/* Pelda 05/08 */

/**
 * Superman. A PrivatEmber osztalybol szarmazik, de belole mar nem szarmazhat
 * masik osztaly, mert final. (A leszarmazas letilthato fuggvenyenkent is. Akkor
 * a fuggveny visszateresi tipusa ele kell a final kulcsszot tenni. Ebben az
 * esetben a fuggveny nem irhato felul a leszarmazott osztalyokban.)
 *
 * @author Akos Kiss
 */
public final class Superman extends PrivatEmber {

  /** A Superman szupererejenek mennyisege. */
  private int szuperero;

  /**
   * Letrehoz egy Superman-t. Megadhato a neve, szuletesi evszama es a neme.
   *
   * @param n a Superman neve.
   * @param sz a Superman szuletesi evszama.
   * @param f a Superman neme (FERFI vagy NO).
   */
  public Superman(String n, int sz, boolean f) {
    // Az ososztaly konstruktorat igy hivjuk. Kotelezoen ez az elso utasitas
    // egy leszarmazott osztaly konstruktoraban. Ha megis elhagyjuk, akkor az
    // ososztaly default konstruktora hivodik.
    super(n, sz, f);

    // Az ebben az osztalyban deklaralt mezok inicializalasa.
    szuperero = 5;
  }

  /**
   * Alapertelmezesben Christopher Reeve a Superman.
   */
  public Superman() {
    // A super() helyett this()-t is irhatunk. Ekkor egy masik sajat 
    // konstruktornak adjuk at a vezerlest. Az elso utasitas kell, hogy legyen.
    this("Christopher Reeve", 1952, FERFI);
  }

  /**
   * Superman megmenti a vilagot, ha tudja.
   *
   * @return true, ha Superman megmenti a vilagot, false, ha mar elfaradt.
   */
  public boolean mentsdMegAVilagot() {
    if (szuperero-- > 0) {
      System.out.println("... es Superman ("+this+") megint megmentette a vilagot!"); // Itt az objektumot String-ge alakitjuk. Lasd lentebb.
      return true;
    }
    else {
      System.out.println("Superman elfaradt. Boldoguljon a vilag ahogy tud!");
      return false;
    }
  }

  /**
   * Az info fuggveny feluldefinialt valtozata.
   */
  public void info() {
    super.info(); // Igy tudjuk hivni az ososztalyban levo valtozatot.
    System.out.println("Ja, megvalami! O Superman!");
  }

  /**
   * Vegso soron minden osztaly a java.lang.Object-bol szarmazik. Abban 
   * definialva van a toString fuggveny, ami megadja, hogy hogyan alakitsunk egy 
   * objektumot String-ge. Az alap megvalositas nem ad ertelmes kimenetet, ezert 
   * celszeru feluldefinialni. (Celszeru lett volna ezt a PrivatEmber osztalyban 
   * megvalositani.)
   *
   * @return a Superman objektum String reprezentacioja.
   */
  public String toString() {
    // Ha az ososztalyban az adatmezok lathatosaga protected lett volna, akkor 
    // nem kellene fuggvenyeket hivni, hanem egyszeruen hozzajuk fernenk.
    return neve() + "," + szulDatumLeker() + "," + (neme() ? "ffi" : "no");
  }

}
