import java.io.*;
import java.util.*;


/**
 * All-in-one pelda a java.util es a java.io csomagok legfontosabb osztalyaira.
 *
 * @author Akos Kiss
 */
public class CollectionsAndIO {

    public static void main(String[] args) throws IOException {
	if (args.length > 2) {
	    System.err.println("Hasznalat: java CollectionsAndIO [inputfile [outputfile]]");
	    System.exit(1);
	}

	// BufferedReader-t ultetunk vagy egy FileReader-re, vagy a standard
	// inputra. Mivel a System.in nem Reader, hanem InputStream, ezert elobb
	// azt Reader-re kell alakitani InputStreamReader-rel. Azert hasznalunk
	// BufferedReader-t Reader helyett, hogy soronkent tudjuk olvasni az
	// inputot.
	BufferedReader r = new BufferedReader((args.length > 0) ? new FileReader(args[0]) : new InputStreamReader(System.in));
	
	// Writer-t fogunk hasznalni a kiirashoz. A System.out nem Writer, ezert
	// OutputStreamWriter-t ultetunk ra.
	Writer w = (args.length > 1) ? new FileWriter(args[1]) : new OutputStreamWriter(System.out);
	
	Random rand = new Random(); // veletlenszam-generator
	Set set = new HashSet(); // halmaz, jelenleg tordelotablaval megvalositva; lehetne faval is (TreeSet)
	List list = new ArrayList(); // lista, jelenleg tomb-bel megvalositva; lehetne lancolt listaval is (LinkedList)
	Map map = new TreeMap(); // asszociativ tomb, jelenleg faval megvalositva (kulcs szerint rendez); lehetne tordelotablaval is (HashMap)

	// beolvassuk soronkent az inputot	
	//for (String line; (line = r.readLine()) != null;) { //Filevegjelig megy: ^Z   (Ctrl-Z, vagy F6).
	//for (String line; !(line = r.readLine()).equals("exit");) { // "exit" string-ig megy
	String line;
	while((line = r.readLine()) != null) {
		if(line.equals("exit"))
			break;
	    // a StringTokenizer-rel whitespace-nel tordeljuk
	    StringTokenizer tokenizer = new StringTokenizer(line);
	    while (tokenizer.hasMoreTokens()) {
		String t = tokenizer.nextToken();
		
		// kulonfele modon berakjuk a kontenerekbe a tokent
		set.add(t);
		list.add(0, t); // itt a tobbi ele szurunk be
		map.put(t, new Integer(rand.nextInt())); // primitiv tipus nem helyezheto kontenerbe, ezert wrap-pelunk
	    }
	}
	r.close();
	
	w.write("{");
	for (Iterator it = set.iterator(); it.hasNext(); ) { // iteratorral bejarjuk a halmazt
	    String t = (String)it.next(); // az iterator Object-et ad vissza, ezert tipuskonvertaljuk
	    w.write(t);
	    if (it.hasNext())
		w.write(",");
	}
	w.write("}\n");
	
	w.write(list.toString()); // a kollekciok toString-je ertelmesen van feluldefinialva
	w.write("\n");
	
	w.write("[");
	for (Iterator it = map.entrySet().iterator(); it.hasNext(); ) { // iteratorral bejarjuk a map elemeit (bejarhattuk volna csak a kulcshalmazt is (.keySet())
	    Map.Entry e = (Map.Entry)it.next();
	    w.write((String)e.getKey()); // errol tudjuk, hogy String
	    w.write("=>");
	    w.write(e.getValue().toString()); // errol meg tudjuk hogy Integer
	    if (it.hasNext())
		w.write(",");
	}
	w.write("]\n");

	w.flush();
	w.close();
    }

}
