import java.io.*;
import java.util.*;


/**
 * All-in-one pelda a java.util es a java.io csomagok legfontosabb osztalyaira.
 *
 * @author Akos Kiss
 * @author Ferenc Fischer
 */
public class CollectionsAndIOGenerics {

    public static void main(String[] args) throws IOException {
	if (args.length > 2) {
	    System.err.println("Hasznalat: java CollectionsAndIOGenerics [inputfile [outputfile]]");
	    System.exit(1);
	}

	// BufferedReader-t ultetunk vagy egy FileReader-re, vagy a standard
	// inputra. Mivel a System.in nem Reader, hanem InputStream, ezert elobb
	// azt Reader-re kell alakitani InputStreamReader-rel. Azert hasznalunk
	// BufferedReader-t Reader helyett, hogy soronkent tudjuk olvasni az
	// inputot.
	BufferedReader r = new BufferedReader((args.length > 0) ? new FileReader(args[0]) : new InputStreamReader(System.in));
	
	// Writer-t fogunk hasznalni a kiirashoz. A System.out nem Writer, ezert
	// OutputStreamWriter-t ultetunk ra.
	Writer w = (args.length > 1) ? new FileWriter(args[1]) : new OutputStreamWriter(System.out);
	
	Random rand = new Random(); // veletlenszam-generator
	Set<String> set = new HashSet<String>(); // halmaz, jelenleg tordelotablaval megvalositva; lehetne faval is (TreeSet) - generikus: String-ek tarolasara
	List<String> list = new ArrayList<String>(); // lista, jelenleg tomb-bel megvalositva; lehetne lancolt listaval is (LinkedList) - generikus: String-ek tarolasara
	Map<String,Integer> map = new TreeMap<String,Integer>(); // asszociativ tomb, jelenleg faval megvalositva (kulcs szerint rendez); lehetne tordelotablaval is (HashMap) - generikus: String-ek is Integer-ek tarolasara

	// beolvassuk soronkent az inputot	
	//for (String line; (line = r.readLine()) != null;) { //Filevegjelig megy: ^Z   (Ctrl-Z, vagy F6).
	//for (String line; !(line = r.readLine()).equals("exit");) { // "exit" string-ig megy
	String line;
	while((line = r.readLine()) != null) {
		if(line.equals("exit"))
			break;
	    // a StringTokenizer-rel whitespace-nel tordeljuk
	    StringTokenizer tokenizer = new StringTokenizer(line);
	    while (tokenizer.hasMoreTokens()) {
		String t = tokenizer.nextToken();
		
		// kulonfele modon berakjuk a kontenerekbe a tokent
		set.add(t);
		list.add(0, t); // itt a tobbi ele szurunk be
		//map.put(t, new Integer(rand.nextInt(1000))); // primitiv tipus nem helyezheto kontenerbe, ezert wrap-pelunk
		map.put(t, rand.nextInt(1000)); // primitiv tipus nem helyezheto kontenerbe, ezert wrap-pelnunk kell, de 5.0 java-ban van Autoboxing and Auto-Unboxing a primitiv tipusokra
	    }
	}
	r.close();
	
	w.write("Set = {");
	for (Iterator<String> it = set.iterator(); it.hasNext(); ) { // iteratorral bejarjuk a halmazt
	    String t = it.next(); // az iterator String-et ad vissza, mivel generikus, ezert nem kell tipuskonvertalni (cast-olni)
	    w.write(t);
	    if (it.hasNext())
	    	w.write(",");
	}
	w.write("}\n");
	
	w.write("Set = {");
	for (String t : set) { // Enhanced for Loop - 5.0
		w.write(t);
		w.write(",");
	}
	w.write("}\n");
	
	w.write("Set = ");
	w.write(set.toString()); // a kollekciok toString-je ertelmesen van feluldefinialva
	w.write("\n");
	
	w.write("List = ");
	w.write(list.toString()); // a kollekciok toString-je ertelmesen van feluldefinialva
	w.write("\n");
	
	w.write("Map = [");
	for (Iterator<Map.Entry<String, Integer>> it = map.entrySet().iterator(); it.hasNext(); ) { // iteratorral bejarjuk a map elemeit (bejarhattuk volna csak a kulcshalmazt is (.keySet())
	    Map.Entry<String,Integer> e = it.next();
	    w.write(e.getKey()); // errol tudjuk, hogy String es mivel generikus tipus, igy nem kell cast-olni
	    w.write("=>");
	    w.write(e.getValue().toString()); // errol meg tudjuk hogy Integer
	    if (it.hasNext())
	    	w.write(",");
	}
	w.write("]\n");
	
	w.write("Map = [");
	for (String key : map.keySet()) {
		w.write(key); 
	    w.write("=>");
	    w.write(map.get(key).toString());
	    w.write(",");
	}
	w.write("]\n");

	w.write("Map = ");
	w.write(map.toString()); // a kollekciok toString-je ertelmesen van feluldefinialva
	w.write("\n");
	
	w.flush();
	w.close();
    }

}
